// Do this as the first thing so that any code reading it knows the right env.
process.env.BABEL_ENV = 'development'
process.env.NODE_ENV = 'development'

/*
    Makes the script crash on unhandled rejections instead of silently
    ignoring them. In the future, promise rejections that are not handled will
    terminate the Node.js process with a non-zero exit code.
 */
process.on('unhandledRejection', (error) => {
    throw error
})

const webpack = require('webpack')
const paths = require('../config/paths')
const WebpackDevServer = require('webpack-dev-server')
const webpackConfig = require('../config/webpack.config.dev')
const { checkBrowsers, printBrowsers } = require('../helper/browsers')
const checkRequiredFiles = require('../helper/check-required-files')
const devServerOptions = require('../config/serve.config.js')

// Add the HMR entry points to the webpackConfig.
WebpackDevServer.addDevServerEntrypoints(webpackConfig, devServerOptions)
// Create a webpack compiler that is webpackConfigured with custom messages.
const compiler = webpack(webpackConfig)
// Serve webpack assets generated by the compiler over a web server.
const devServer = new WebpackDevServer(compiler, devServerOptions)

// Warn and crash if required files are missing
if (!checkRequiredFiles([paths.appIndexHtml, paths.appIndexTsx])) {
    process.exit(1)
}

// Locate HOST/PORT
const PORT = parseInt(process.env.PORT, 10) || 3000
const HOST = process.env.HOST || '0.0.0.0'

checkBrowsers(paths.appPath)
    .then(() => printBrowsers(paths.appPath))
    .then(() =>
        devServer.listen(PORT, HOST, (err) => {
            if (err) {
                return console.log(err)
            }

            console.log(`webpack-dev-server listening on ${HOST}:${PORT}`)
        })
    )
    .catch((error) => {
        if (error && error.message) {
            console.log(error.message)
        }

        process.exit(1)
    })
